4.5. oncilla.reStructuredTextToHtml — Oncilla 0.1.0 documentation

# 4.5. oncilla.reStructuredTextToHtml

reStructuredTextToHtml.py

Platform:
  Windows, Linux, Mac Os X.
Description:
  Converts a reStructuredText file to html.

Others:

## 4.5.1. Module Attributes

`oncilla.reStructuredTextToHtml.` `LOGGER`

`oncilla.reStructuredTextToHtml.` `RESOURCES_DIRECTORY`

`oncilla.reStructuredTextToHtml.` `CSS_FILE`

`oncilla.reStructuredTextToHtml.` `TIDY_SETTINGS_FILE`

`oncilla.reStructuredTextToHtml.` `RST2HTML`

## 4.5.2. Functions

`oncilla.reStructuredTextToHtml.` `reStructuredTextToHtml`(input, output, cssFile)

  Outputs a reStructuredText file to html.

  Parameters: | input (unicode) – Input reStructuredText file to convert. output (unicode) – Output html file. cssFile (unicode) – Css file.
  Returns: | Definition success.
  Return type: | bool

`oncilla.reStructuredTextToHtml.` `getCommandLineArguments`()

  Retrieves command line arguments.

  Returns: | Namespace.
  Return type: | Namespace

`oncilla.reStructuredTextToHtml.` `main`()

  Starts the Application.

  Returns: | Definition success.
  Return type: | bool